===============================
Tweet RSS Feed
===============================

.. image:: https://badge.fury.io/py/tweetrssfeed.png
    :target: http://badge.fury.io/py/tweetrssfeed
    
.. image:: https://travis-ci.org/gam-phon/tweetrssfeed.png?branch=master
        :target: https://travis-ci.org/gam-phon/tweetrssfeed

.. image:: https://pypip.in/d/tweetrssfeed/badge.png
        :target: https://crate.io/packages/tweetrssfeed?version=latest


Tweet RSS Feeds

* Free software: BSD license
* Documentation: http://tweetrssfeed.rtfd.org.

Inspired by: http://halotis.com/2009/07/01/rss-twitter-bot-in-python/

Features
--------

* TODO